﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using NHibernate;
using NHibernate.Cfg;
using NHibernate.Linq;

namespace NHibernateLinq
{
    class SampleContext : NHibernateContext
    {
        public SampleContext( ISession session ) : base( session ) { }

        public IOrderedQueryable<Koszyk> Koszyk
        {
            get { return Session.Linq<Koszyk>(); }
        }

        public IOrderedQueryable<Produkt> Produkt
        {
            get { return Session.Linq<Produkt>(); }
        }
    }

    class Program
    {
        static ISession OpenSession()
        {
            return new Configuration().Configure().BuildSessionFactory().OpenSession();
        }
        static void Main( string[] args )
        {
            ISession session = OpenSession();
            var context = new SampleContext( session );

            {
                Console.WriteLine( "------- Proste zapytanie -------" );

                var result = from k in context.Koszyk
                             where k.S_Produkty.Count > 0
                             select k;
                foreach ( var r in result )
                {
                    Console.WriteLine( "{0} {1} {2}", r.ID, r.Klient, r.S_Produkty.Count );
                }
            }

            {
                Console.WriteLine( "------- Grupowanie -------" );

                var result = from p in context.Produkt
                             group p by new { DuzaCena = p.Cena } into g
                             select new { k = g.Key.DuzaCena, l = g.Count() };

                foreach ( var r in result )
                {
                    Console.WriteLine( "{0} {1}", r.k, r.l );
                }
            }
            session.Close();
        }
    }
}
